@@ -59,6 +59,9 @@ public:
 
   const char *c_str() noexcept;
 
+  std::size_t capacity() const noexcept;
+  void reserve(size_t new_cap) noexcept;
+
   using iterator = char *;
   iterator begin() noexcept;
   iterator end() noexcept;
@@ -338,7 +341,7 @@ public:
   Vec(unsafe_bitcopy_t, const Vec &) noexcept;
 
 private:
-  void reserve_total(std::size_t cap) noexcept;
+  void reserve_total(std::size_t new_cap) noexcept;
   void set_len(std::size_t len) noexcept;
   void drop() noexcept;
 
